@@ -13,15 +13,10 @@ pub fn agent_info() -> ExternResult<AgentInfo> {
     HDK.with(|h| h.borrow().agent_info(()))
 }
 
-/// @todo Not implemented
-pub fn app_info() -> ExternResult<AppInfo> {
-    HDK.with(|h| h.borrow().app_info(()))
-}
-
 /// Get the DNA information.
 /// There are no inputs to [ `dna_info` ].
 ///
-/// DNA information includes dna name, hash and properties.
+/// DNA information includes dna name, hash, properties, and zome names.
 pub fn dna_info() -> ExternResult<DnaInfo> {
     HDK.with(|h| h.borrow().dna_info(()))
 }
